@@ -2,7 +2,7 @@
                           main.cpp  -  main program
                              -------------------
     begin                : sam déc  1 23:40:19 CET 2001
-    copyright            : (C) 2001-2009 by Éric Bischoff
+    copyright            : (C) 2001-2010 by Éric Bischoff
     email                : ebischoff@nerim.net
  ***************************************************************************/
 
@@ -30,17 +30,17 @@
 static const char
 	*name = I18N_NOOP("KEuroCalc"),
 	*description = I18N_NOOP("Cash converter and calculator"),
-	*copyright = I18N_NOOP("(c) 2001-2009, the KEuroCalc developers"),
+	*copyright = I18N_NOOP("(c) 2001-2010, the KEuroCalc developers"),
 	*text = I18N_NOOP("A program by Éric Bischoff <ebischoff@nerim.net>\n\nThis program is dedicated to humorist Michael Moore, for he\nknows that money does not justify anything...\n");
 
 int main(int argc, char *argv[])
 {
-	KAboutData aboutData("keurocalc", "keurocalc", ki18n(name), "1.0.2", ki18n(description),
+	KAboutData aboutData("keurocalc", "keurocalc", ki18n(name), "1.0.3", ki18n(description),
 			     KAboutData::License_GPL, ki18n(copyright), ki18n(text));
 	KCmdLineOptions options;
 
 	aboutData.addAuthor(ki18n("Éric Bischoff"), ki18n("Design and implementation"), "ebischoff@nerim.net");
-	aboutData.addAuthor(ki18n("Gil Gross"), ki18n("Additional functionnality"), "ptit.ours@gmail.com");
+	aboutData.addAuthor(ki18n("Gil Gross"), ki18n("Additional functionality"), "ptit.ours@gmail.com");
 	aboutData.addCredit(ki18n("Melchior Franz"), ki18n("Design and testing"), "a8603365@unet.univie.ac.at");
 	aboutData.addCredit(ki18n("Bas Willems"), ki18n("Graphical artwork"), "cybersurfer@euronet.nl");
 	aboutData.setOrganizationDomain("kde.org");
